@@ -14,14 +14,14 @@ function _aws_cdk_aws_servicecatalogappregistry_IAttributeGroup(p) {
 }
 function _aws_cdk_aws_servicecatalogappregistry_IApplication(p) {
 }
-function _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociation(p) {
-}
 function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociation(p) {
 }
-function _aws_cdk_aws_servicecatalogappregistry_CfnApplication(p) {
+function _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociation(p) {
 }
 function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroup(p) {
 }
+function _aws_cdk_aws_servicecatalogappregistry_CfnApplication(p) {
+}
 function _aws_cdk_aws_servicecatalogappregistry_AttributeGroup(p) {
 }
 function _aws_cdk_aws_servicecatalogappregistry_Application(p) {
@@ -41,5 +41,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociationProps, _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociationProps, _aws_cdk_aws_servicecatalogappregistry_ApplicationProps, _aws_cdk_aws_servicecatalogappregistry_AttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_CfnApplicationProps, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_IAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_IApplication, _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociation, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociation, _aws_cdk_aws_servicecatalogappregistry_CfnApplication, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_AttributeGroup, _aws_cdk_aws_servicecatalogappregistry_Application };
+module.exports = { print, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociationProps, _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociationProps, _aws_cdk_aws_servicecatalogappregistry_ApplicationProps, _aws_cdk_aws_servicecatalogappregistry_AttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_CfnApplicationProps, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_IAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_IApplication, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociation, _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociation, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_CfnApplication, _aws_cdk_aws_servicecatalogappregistry_AttributeGroup, _aws_cdk_aws_servicecatalogappregistry_Application };
 module.exports.DeprecationError = DeprecationError;
